@@ -11,6 +11,7 @@ from collections import defaultdict
 from nbdime import merge_notebooks, diff
 from nbdime.diff_format import op_patch
 from nbdime.utils import Strategies
+from nbdime.diffing.config import DiffConfig
 from nbdime.merging.generic import decide_merge, decide_merge_with_diff
 from nbdime.merging.decisions import apply_decisions
 from nbdime.merging.strategies import _cell_marker_format
@@ -177,7 +178,6 @@ def test_decide_merge_simple_list_insert_conflict_resolution():
     assert apply_decisions(b, decisions) == []
     assert not any(d.conflict for d in decisions)
 
-@pytest.mark.skip
 def test_decide_merge_simple_list_insert_conflict_resolution__union():
     # local and remote adds an entry each
     b = [1]
@@ -281,7 +281,6 @@ def test_decide_merge_list_conflicting_insertions_separate_chunks_v2():
     assert not resolved[1].conflict
 
 
-@pytest.mark.skip
 def test_decide_merge_list_conflicting_insertions_separate_chunks__union():
     # local and remote adds an equal entry plus a different entry each
     # First, test when insertions DO NOT chunk together:
@@ -328,7 +327,6 @@ def test_decide_merge_list_conflicting_insertions_in_chunks():
     assert not any(d.conflict for d in resolved)
 
 
-@pytest.mark.skip
 def test_decide_merge_list_conflicting_insertions_in_chunks__union():
     # Next, test when insertions DO chunk together:
     b = [1, 9]
@@ -344,9 +342,11 @@ def test_decide_merge_list_conflicting_insertions_in_chunks__union():
 def test_decide_merge_list_transients():
     # For this test, we need to use a custom predicate to ensure alignment
     common = {'id': 'This ensures alignment'}
-    predicates = defaultdict(lambda: [operator.__eq__], {
-        '/': [lambda a, b: a['id'] == b['id']],
-    })
+    config = DiffConfig(
+        predicates=defaultdict(lambda: [operator.__eq__], {
+            '/': [lambda a, b: a['id'] == b['id']],
+        })
+    )
 
     # Setup transient difference in base and local, deletion in remote
     b = [{'transient': 22}]
@@ -356,8 +356,8 @@ def test_decide_merge_list_transients():
     r = []
 
     # Make decisions based on diffs with predicates
-    ld = diff(b, l, path="", predicates=predicates)
-    rd = diff(b, r, path="", predicates=predicates)
+    ld = diff(b, l, path="", config=config)
+    rd = diff(b, r, path="", config=config)
 
     # Assert that generic merge without strategies gives conflict:
     strategies = Strategies()
@@ -400,9 +400,11 @@ def test_decide_merge_dict_transients():
 def test_decide_merge_mixed_nested_transients():
     # For this test, we need to use a custom predicate to ensure alignment
     common = {'id': 'This ensures alignment'}
-    predicates = defaultdict(lambda: [operator.__eq__], {
-        '/': [lambda a, b: a['id'] == b['id']],
-    })
+    config = DiffConfig(
+        predicates=defaultdict(lambda: [operator.__eq__], {
+            '/': [lambda a, b: a['id'] == b['id']],
+        })
+    )
     # Setup transient difference in base and local, deletion in remote
     b = [{'a': {'transient': 22}}]
     l = [{'a': {'transient': 242}}]
@@ -411,8 +413,8 @@ def test_decide_merge_mixed_nested_transients():
     r = []
 
     # Make decisions based on diffs with predicates
-    ld = diff(b, l, path="", predicates=predicates)
-    rd = diff(b, r, path="", predicates=predicates)
+    ld = diff(b, l, path="", config=config)
+    rd = diff(b, r, path="", config=config)
 
     # Assert that generic merge gives conflict
     strategies = Strategies()
